==> qt6-tools-6.2.3-4-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6ToolsTools/Qt6ToolsToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qhelpgenerator" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qhelpgenerator APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qhelpgenerator PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/qhelpgenerator"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qhelpgenerator )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qhelpgenerator "${_IMPORT_PREFIX}/lib/qt6/bin/qhelpgenerator" )

# Import target "Qt6::qtattributionsscanner" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qtattributionsscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qtattributionsscanner PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/qtattributionsscanner"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qtattributionsscanner )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qtattributionsscanner "${_IMPORT_PREFIX}/lib/qt6/qtattributionsscanner" )

# Import target "Qt6::qdoc" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qdoc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qdoc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/qdoc"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qdoc )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qdoc "${_IMPORT_PREFIX}/lib/qt6/bin/qdoc" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qt6-tools-6.4.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6ToolsTools/Qt6ToolsToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qhelpgenerator" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qhelpgenerator APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qhelpgenerator PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/qhelpgenerator"
  )

list(APPEND _cmake_import_check_targets Qt6::qhelpgenerator )
list(APPEND _cmake_import_check_files_for_Qt6::qhelpgenerator "${_IMPORT_PREFIX}/lib/qt6/qhelpgenerator" )

# Import target "Qt6::qtattributionsscanner" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qtattributionsscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qtattributionsscanner PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/qtattributionsscanner"
  )

list(APPEND _cmake_import_check_targets Qt6::qtattributionsscanner )
list(APPEND _cmake_import_check_files_for_Qt6::qtattributionsscanner "${_IMPORT_PREFIX}/lib/qt6/qtattributionsscanner" )

# Import target "Qt6::qdoc" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qdoc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qdoc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/qdoc"
  )

list(APPEND _cmake_import_check_targets Qt6::qdoc )
list(APPEND _cmake_import_check_files_for_Qt6::qdoc "${_IMPORT_PREFIX}/lib/qt6/bin/qdoc" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
